@@ -16,7 +16,7 @@ use Term::ANSIColor qw/colored/;
 use File::ShareDir qw/dist_dir/;
 use Path::Tiny;
 
-our $VERSION = "0.006";
+our $VERSION = "0.007";
 
 has [qw/base_url api_key api_pass test/] => (
     is => 'rw',
@@ -305,14 +305,32 @@ sub _action {
     my ($self, $depth, $query, $action) = @_;
     my $jenkins = $self->jenkins();
 
-    my $data = $jenkins->_json_api([qw/api json/], { extra_params => { depth => $depth } });
+    my $data = eval {
+        $jenkins->_json_api([qw/api json/], { extra_params => { depth => $depth } });
+    };
+
+    if ( ! $data || $@ ) {
+        my $err = $@ ? ": $@" : '';
+        die "No data found! (can't talk to Jenkins Server?)$err\n";
+    }
 
     my $re = $self->opt->regexp ? qr/$query/ : qr/\A\Q$query\E\Z/;
 
     for my $job (sort _alpha_num @{ $data->{jobs} }) {
         next if $query && $job->{name} !~ /$re/;
+
         local $_ = $job;
 
+        if ( $self->opt->{recipient} ) {
+            my $config = $jenkins->project_config($_->{name});
+            require XML::Simple;
+            local $Data::Dumper::Sortkeys = 1;
+            local $Data::Dumper::Indent = 1;
+            my $data = XML::Simple::XMLin($config);
+            my $recipient = $self->opt->{recipient};
+            next if $data->{publishers}{'hudson.tasks.Mailer'}{recipients} !~ /$recipient/;
+        }
+
         $self->$action();
     }
 
@@ -389,7 +407,7 @@ App::JenkinsCli - Command line tool for interacting with Jenkins
 
 =head1 VERSION
 
-This documentation refers to App::JenkinsCli version 0.006
+This documentation refers to App::JenkinsCli version 0.007
 
 =head1 SYNOPSIS
 
